@@ -232,7 +232,7 @@ void board_2d::resizeBoard( void )
 ///////////////////////////////////////
 void board_2d::redrawAll( void )
 {
-	register char tmp(0);
+	char tmp(0);
 
 	if( init )
 		return;
@@ -583,7 +583,7 @@ void board_2d::mouseMoveEvent( TQMouseEvent *event )
 TQPixmap board_2d::getChessman( const int &pos )
 {
 	TQPixmap tmp;
-	register char type, army;
+	char type, army;
 
 	if( pos == premoveTo )
 	{
