@@ -16,8 +16,8 @@
  ***************************************************************************/
 
 /* KDE */
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 
 /* TQt */
 #include <tqpushbutton.h>
